<?php
/** Kalaallisut (Kalaallisut)
 *
 * @ingroup Language
 * @file
 *
 * @author לערי ריינהארט
 */

$fallback = 'da';

$messages = array(
# Dates
'sun'           => 'Sap',
'mon'           => 'Ata',
'tue'           => 'Mar',
'wed'           => 'Pin',
'thu'           => 'Sis',
'fri'           => 'Tal',
'sat'           => 'Arf',
'january'       => 'Januaari',
'february'      => 'Februaari',
'march'         => 'Marsi',
'april'         => 'Apriili',
'may_long'      => 'Maaji',
'june'          => 'Juuni',
'july'          => 'Juuli',
'august'        => 'Aggusti',
'september'     => 'Septembari',
'october'       => 'Oktobari',
'november'      => 'Novembari',
'december'      => 'Decembari',
'january-gen'   => 'Januaari',
'february-gen'  => 'Februaari',
'march-gen'     => 'Marsi',
'april-gen'     => 'Apriili',
'may-gen'       => 'Maaji',
'june-gen'      => 'Juuni',
'july-gen'      => 'Juuli',
'august-gen'    => 'Aggusti',
'september-gen' => 'Septembari',
'october-gen'   => 'Oktobari',
'november-gen'  => 'Novembari',
'december-gen'  => 'Decembari',
'jan'           => 'Jan',
'feb'           => 'Feb',
'mar'           => 'Mar',
'apr'           => 'Apr',
'may'           => 'Maa',
'jun'           => 'Juu',
'jul'           => 'Juu',
'aug'           => 'Agg',
'sep'           => 'Sep',
'oct'           => 'Okt',
'nov'           => 'Nov',
'dec'           => 'Dec',

'about'  => 'Pillugu',
'cancel' => 'Unitsitsivoq',
'qbedit' => 'Aaqqissuutiguk',

'errorpagetitle'   => 'Kukkuneq',
'tagline'          => 'Matumannga {{SITENAME}}',
'help'             => 'Ikiortissamik',
'search'           => 'Ujaarlerit',
'searchbutton'     => 'Ujaarlerit',
'go'               => 'Ikunnarit',
'searcharticle'    => 'Pisuppoq',
'history_short'    => 'Historiki',
'edit'             => 'Aaqqissuutiguk',
'protect'          => 'Illersorpaa',
'talkpagelinktext' => 'Oqallinneq',
'talk'             => 'Oqallinneq',
'toolbox'          => 'Sannataasivik',
'otherlanguages'   => 'Oqaatsit allat',
'jumptonavigation' => 'navigationi',
'jumptosearch'     => 'ujaarlerit',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'            => '{{SITENAME}} pillugu',
'aboutpage'            => 'Project:Pillugu',
'currentevents'        => 'Maannakkut pisut',
'mainpage'             => 'Saqqaa',
'mainpage-description' => 'Saqqaa',
'portal'               => 'Allaatiginnittartup saqqai',

'editsection'     => 'aaqqissuutiguk',
'editold'         => 'aaqqissuutiguk',
'editsectionhint' => 'Aaqqissuutiguk immikkoortoq: $1',
'site-rss-feed'   => '$1 RSS Feed',
'site-atom-feed'  => '$1 Atom Feed',
'page-rss-feed'   => '"$1" RSS Feed',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-image'    => 'Assiliaq',
'nstab-template' => 'Skabeloni',
'nstab-category' => 'Suussuseq',

# Login and logout pages
'yourname'                   => 'Pineqartoqateq:',
'acct_creation_throttle_hit' => 'Utoqqatterpunga, $1 kontonik pilersereersimavutit. Pilersitseqqissinnaanngilatit.',

# Edit pages
'summary'      => 'Qanoq issusersiuineq:',
'accmailtitle' => 'Password-i nassiunneqarsimavoq.',
'accmailtext'  => 'Password-i "$1" $2-mut nassiunneqarsimavoq.',
'newarticle'   => '(Nuutaq)',

# Search results
'powersearch' => 'Ujaarlerit',

# Recent changes
'recentchanges'   => 'Allannguutit kingulliit',
'hist'            => 'hist',
'minoreditletter' => 'm',
'newpageletter'   => 'N',
'boteditletter'   => 'b',

# Recent changes linked
'recentchangeslinked' => 'Allannguutit naleqqiussat',

# Upload
'upload' => 'Læg en fil op',

# File description page
'filehist-user' => 'Pineqartoq',

# MIME search
'mimesearch' => 'MIME ujaarlerit',

# Random page
'randompage' => 'Nalaatsorluni atuagassianut ilanngutassiaq',

# Statistics
'statistics' => 'Kisitsisinngorlugit paasissutissat',

# Miscellaneous special pages
'move' => 'Nuunneq',

# Special:Log
'specialloguserlabel' => 'Pineqartoq:',

# Special:AllPages
'allpagessubmit' => 'Pisuppoq',

# Watchlist
'addedwatch'     => 'Nakkutilliinermi allattorsimaffimmut ilanngunneqarsimavoq',
'addedwatchtext' => "Qupperneq \"[[:\$1]]\" ilanngunneqarsimavoq [[Special:Watchlist|nakkutilliinermut allattorsimaffimmut]] ilanngunneqarsimavoq. Matumani quppernermi siunissami allannguutit, aammalu oqallinnermi qupperneq, maani saqqummersinneqassapput, quppernerlu '''erseqqissagaasoq''' inisseqqassalluni [[Special:RecentChanges|allattorsimaffik kingullermi allannguutinik imalik]] ajornannginnerussammat nassaariniarnissaanut.

Qupperneq nakkutilliinermi allattorsimaffik kingusinnerusukkut piissagukku, taava quppernerup sinaatungaani \"Nakkutilliinermi allattorsimaffik peeruk\" tooruk.",
'watch'          => 'Piggassineq',

# Delete
'actioncomplete' => 'Naammassineqareersimavoq',

# Protect
'prot_1movedto2' => '[[$1]]-i nuunneqarsimavoq [[$2]]-mut',

# Contributions
'uctop' => '(kaarfa)',

# What links here
'whatlinkshere' => 'Suna maangamut innersuussivoq',

# Block/unblock
'blocklink' => 'aporfeqarneq',

# Move page
'1movedto2'       => '[[$1]]-i nuunneqarsimavoq [[$2]]-mut',
'1movedto2_redir' => '[[$1]] nuunneqarsimavoq [[$2]]-mut adresse-ia aqqutigalugu allanngortillugu',

# Tooltip help for the actions
'tooltip-search' => 'Ujaarlerit {{SITENAME}}',

# Special:SpecialPages
'specialpages' => 'Quppernerit immikkut ittut',

);
